@@ -1,22 +1,10 @@
 """
-  Copyright 2019 Amazon.com, Inc. or its affiliates. All Rights Reserved.
-
-  Permission is hereby granted, free of charge, to any person obtaining a copy of this
-  software and associated documentation files (the "Software"), to deal in the Software
-  without restriction, including without limitation the rights to use, copy, modify,
-  merge, publish, distribute, sublicense, and/or sell copies of the Software, and to
-  permit persons to whom the Software is furnished to do so.
-
-  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED,
-  INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
-  PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
-  HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
-  OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
-  SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
+SPDX-License-Identifier: MIT-0
 """
 import six
-from cfnlint import CloudFormationLintRule
-from cfnlint import RuleMatch
+from cfnlint.rules import CloudFormationLintRule
+from cfnlint.rules import RuleMatch
 import cfnlint.helpers
 
 
@@ -55,7 +43,7 @@ class GetAtt(CloudFormationLintRule):
                 matches.append(RuleMatch(getatt, message.format('/'.join(map(str, getatt[:-1])))))
                 continue
             if isinstance(getatt[-1], six.string_types):
-                resname, restype = getatt[-1].split('.')
+                resname, restype = getatt[-1].split('.', 1)
             else:
                 resname = None
                 restype = None
@@ -79,13 +67,15 @@ class GetAtt(CloudFormationLintRule):
                                             '/'.join(map(str, getatt[:-1])))))
                     else:
                         message = 'Invalid GetAtt structure {0} at {1}'
-                        matches.append(RuleMatch(getatt, message.format(getatt[-1], '/'.join(map(str, getatt[:-1])))))
+                        matches.append(RuleMatch(getatt, message.format(
+                            getatt[-1], '/'.join(map(str, getatt[:-1])))))
 
                     # setting restype to None as we can't validate that anymore
                     restype = None
                 else:
                     message = 'Invalid GetAtt structure {0} at {1}'
-                    matches.append(RuleMatch(getatt, message.format(getatt[-1], '/'.join(map(str, getatt[:-1])))))
+                    matches.append(RuleMatch(getatt, message.format(
+                        getatt[-1], '/'.join(map(str, getatt[:-1])))))
 
             # only check resname if its set.  if it isn't it is because of bad structure
             # and an error is already provided
