@@ -1,8 +1,10 @@
 """
-Copyright 2019 Amazon.com, Inc. or its affiliates. All Rights Reserved.
+Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 SPDX-License-Identifier: MIT-0
 """
 import six
+
+from cfnlint.helpers import valid_snapshot_types
 from cfnlint.rules import CloudFormationLintRule
 from cfnlint.rules import RuleMatch
 
@@ -25,15 +27,6 @@ class UpdateReplacePolicy(CloudFormationLintRule):
             'Snapshot'
         ]
 
-        valid_snapshot_types = [
-            'AWS::EC2::Volume',
-            'AWS::ElastiCache::CacheCluster',
-            'AWS::ElastiCache::ReplicationGroup',
-            'AWS::Neptune::DBCluster',
-            'AWS::RDS::DBCluster',
-            'AWS::RDS::DBInstance',
-            'AWS::Redshift::Cluster',
-        ]
         if not isinstance(key, (six.text_type, six.string_types)):
             message = 'UpdateReplacePolicy values should be of string at {0}'
             matches.append(RuleMatch(path, message.format('/'.join(map(str, path)))))
